@@ -45,13 +45,29 @@ class Foundry(FoundryMetadata):
     dlhub_client: Any
     forge_client: Any
     connect_client: Any
+    index = ""
 
     xtract_tokens: Any
 
     def __init__(
         self, no_browser=False, no_local_server=False, index="mdf-test", authorizers=None, **data
     ):
+        """Initialize a Foundry client
+        Args:
+            no_browser (bool):  Whether to open the browser for the Globus Auth URL.
+            no_local_server (bool): Whether a local server is available.
+                    This should be `False` when on remote server (e.g., Google Colab ).
+            index (str): Index to use for search and data publication. Choices `mdf` or `mdf-test`
+            authorizers (dict): A dictionary of authorizers to use, following the `mdf_toolbox` format
+            data (dict): Other arguments, e.g., results from an MDF search result that are used
+                    to populate Foundry metadata fields
+
+        Returns
+        -------
+            an initialized and authenticated Foundry client
+        """
         super().__init__(**data)
+        self.index = index
 
         if authorizers:
             auths = authorizers
@@ -103,7 +119,6 @@ class Foundry(FoundryMetadata):
         )
 
 
-
         self.xtract_tokens = {
             "auth_token": auths["petrel"].access_token,
             "transfer_token": auths["transfer"].authorizer.access_token,
@@ -165,7 +180,9 @@ class Foundry(FoundryMetadata):
 
         del res["projects"][self.config.metadata_key]
 
-        self = Foundry(**res, authorizers=authorizers)
+        # TODO: Creating a new Foundry instance is a problematic way to update the metadata,
+        # we should find a way to abstract this.
+        self = Foundry(**res, index=self.index, authorizers=authorizers)
 
         if download is True:  # Add check for package existence
             self.download(
@@ -557,8 +574,9 @@ class Foundry(FoundryMetadata):
                         "Unexpected number of files in directory -- dataset will be redownloaded.")
 
         res = self.forge_client.search(
-            "mdf.source_id:{name}".format(name=self.mdf["source_id"]), advanced=True
+            f'mdf.source_id: {self.mdf["source_id"]}', advanced=True
         )
+
         if globus:
             self.forge_client.globus_download(
                 res,
